kedro.framework.hooks.specs.RegistrationSpecs — Kedro 0.17.6 documentation

# kedro.framework.hooks.specs.RegistrationSpecs

class `kedro.framework.hooks.specs.` `RegistrationSpecs`

  Namespace that defines all specifications for hooks registering library components with a Kedro project.

  Methods

  `register_catalog`(catalog, credentials, …) | Hook to be invoked to register a project’s data catalog.
  `register_config_loader`(conf_paths, env, …) | Hook to be invoked to register a project’s config loader.
  `register_pipelines`() | Hook to be invoked to register a project’s pipelines.

  `register_catalog`(catalog, credentials, load_versions, save_version, journal)

    Hook to be invoked to register a project’s data catalog.

    Return type

      `DataCatalog`

    Returns

      An instance of a `DataCatalog`.

  `register_config_loader`(conf_paths, env, extra_params)

    Hook to be invoked to register a project’s config loader.

    Parameters

      - conf_paths (`Iterable`[`str`]) – the paths to the conf directory to be supplied to the config loader

      - env (`str`) – the environment with which the config loader will be instantiated

      - extra_params (`Dict`[`str`, `Any`]) – the extra parameters passed to a Kedro run

    Return type

      `ConfigLoader`

    Returns

      An instance of a `ConfigLoader`.

  `register_pipelines`()

    Hook to be invoked to register a project’s pipelines.

    Return type

      `Dict`[`str`, `Pipeline`]

    Returns

      A mapping from a pipeline name to a `Pipeline` object.